
from distutils.core import setup

setup(

       name = 'ishanaapurba',
       version = '1.0.0',
       py_modules = ['ishanaapurba'],
       author = 'Abhishek Kashyap',
       author_email = 'aabhishek2010@gmail.com',
       url = 'http://www.headfirstlabs.com',
       description = 'A simple printer of listed items',

    )



""" This is a comment
This to show how comment works
Thi sis ho it works"""

def mylist(mystr):
    for item in mystr:
        if isinstance(item,list):
            mylist(item)
        else:
            print (item)
